Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5652)

Unified Diff: chromecast/browser/cast_browser_main_parts.cc

Issue 2845973005: Reland of name kDisableGestureRequirementForMediaPlayback and make it a test-only flag. (Closed)
Patch Set: Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chromecast/browser/cast_browser_main_parts.cc
diff --git a/chromecast/browser/cast_browser_main_parts.cc b/chromecast/browser/cast_browser_main_parts.cc
index ccb0fa874aa8c87c1a354ff3640c59041160c6de..4cf893e2e80f0165d821c98e296683064d6842c2 100644
--- a/chromecast/browser/cast_browser_main_parts.cc
+++ b/chromecast/browser/cast_browser_main_parts.cc
@@ -216,48 +216,50 @@
DefaultCommandLineSwitch g_default_switches[] = {
#if defined(OS_ANDROID)
- // Disables Chromecast-specific WiFi-related features on ATV for now.
- { switches::kNoWifi, "" },
- { switches::kDisableGestureRequirementForMediaPlayback, ""},
- { switches::kDisableMediaSuspend, ""},
-#else
- // GPU shader disk cache disabling is largely to conserve disk space.
- { switches::kDisableGpuShaderDiskCache, "" },
- // Enable media sessions by default (even on non-Android platforms).
- { switches::kEnableDefaultMediaSession, "" },
+ // Disables Chromecast-specific WiFi-related features on ATV for now.
+ {switches::kNoWifi, ""},
+ // TODO(714676): this should probably set the no restrictions autoplay
+ // policy instead.
+ {switches::kIgnoreAutoplayRestrictionsForTests, ""},
+ {switches::kDisableMediaSuspend, ""},
+#else
+ // GPU shader disk cache disabling is largely to conserve disk space.
+ {switches::kDisableGpuShaderDiskCache, ""},
+ // Enable media sessions by default (even on non-Android platforms).
+ {switches::kEnableDefaultMediaSession, ""},
#endif
#if BUILDFLAG(IS_CAST_AUDIO_ONLY)
#if defined(OS_ANDROID)
- { switches::kDisableGLDrawingForTests, "" },
-#else
- { switches::kDisableGpu, "" },
+ {switches::kDisableGLDrawingForTests, ""},
+#else
+ {switches::kDisableGpu, ""},
#endif // defined(OS_ANDROID)
#endif // BUILDFLAG(IS_CAST_AUDIO_ONLY)
#if defined(OS_LINUX)
#if defined(ARCH_CPU_X86_FAMILY)
- // This is needed for now to enable the x11 Ozone platform to work with
- // current Linux/NVidia OpenGL drivers.
- { switches::kIgnoreGpuBlacklist, ""},
+ // This is needed for now to enable the x11 Ozone platform to work with
+ // current Linux/NVidia OpenGL drivers.
+ {switches::kIgnoreGpuBlacklist, ""},
#elif defined(ARCH_CPU_ARM_FAMILY)
#if !BUILDFLAG(IS_CAST_AUDIO_ONLY)
- {switches::kEnableHardwareOverlays, "cast"},
+ {switches::kEnableHardwareOverlays, "cast"},
#endif
#endif
#endif // defined(OS_LINUX)
- // Needed so that our call to GpuDataManager::SetGLStrings doesn't race
- // against GPU process creation (which is otherwise triggered from
- // BrowserThreadsStarted). The GPU process will be created as soon as a
- // renderer needs it, which always happens after main loop starts.
- { switches::kDisableGpuEarlyInit, "" },
- // TODO(halliwell): Cast builds don't support ES3. Remove this switch when
- // support is added (crbug.com/659395)
- { switches::kDisableES3GLContext, "" },
- // Enable navigator.connection API.
- // TODO(derekjchow): Remove this switch when enabled by default.
- { switches::kEnableNetworkInformation, "" },
- // TODO(halliwell): Remove after fixing b/35422666.
- { switches::kEnableUseZoomForDSF, "false" },
- { NULL, NULL }, // Termination
+ // Needed so that our call to GpuDataManager::SetGLStrings doesn't race
+ // against GPU process creation (which is otherwise triggered from
+ // BrowserThreadsStarted). The GPU process will be created as soon as a
+ // renderer needs it, which always happens after main loop starts.
+ {switches::kDisableGpuEarlyInit, ""},
+ // TODO(halliwell): Cast builds don't support ES3. Remove this switch when
+ // support is added (crbug.com/659395)
+ {switches::kDisableES3GLContext, ""},
+ // Enable navigator.connection API.
+ // TODO(derekjchow): Remove this switch when enabled by default.
+ {switches::kEnableNetworkInformation, ""},
+ // TODO(halliwell): Remove after fixing b/35422666.
+ {switches::kEnableUseZoomForDSF, "false"},
+ {nullptr, nullptr}, // Termination
};
void AddDefaultCommandLineSwitches(base::CommandLine* command_line) {
« no previous file with comments | « chrome/renderer/chrome_content_renderer_client.cc ('k') | content/browser/media/encrypted_media_browsertest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698